
#
# Macro:      AP_PROG_APXS
# Author:     Heiko Hund <heiko@ist.eigentlich.net>
# Version:    $Revision: 36 $ $Date: 2007-10-29 21:29:34 +0100 (Mon, 29 Oct 2007) $
# Parameters: none
# Requires:   none
# Output:     @APXS@ - path to apxs
#
# The AP_PROG_APXS macro looks for the apache extension tool (apxs or apxs2)
# in $PATH. It's also possible to give autoconf the right path to apxs via
# `APXS' environment variable or `--with-apxs' switch on the command line.
# If no apxs can be found an error is displayed and configure stops.
#
AC_DEFUN([AP_PROG_APXS],
[
	AC_ARG_VAR([APXS], [path to apache extension tool (apxs)])
	AC_ARG_WITH(
		[apxs],
		[AS_HELP_STRING([--with-apxs], [path to apache extension tool (apxs)])],
		[
			AC_MSG_CHECKING([for apxs])
			if test ! -x "$withval"
			then
				AC_MSG_RESULT([no ($withval is not executable)])
			else
				AC_MSG_RESULT([$withval])
				AC_SUBST([APXS], [$withval])
			fi
		],
		[AC_PATH_PROGS([APXS], [apxs apxs2])]
	)

	if test "x$APXS" = "x"
	then
		AC_MSG_ERROR([The apache extension tool (apxs) was not found in your PATH. You
                  might want to specify the correct path using `--with-apxs'.])
	fi
])



#
# Macro:      AP_HTTPD_VERSION
# Author:     Heiko Hund <heiko@ist.eigentlich.net>
# Version:    $Revision: 36 $ $Date: 2007-10-29 21:29:34 +0100 (Mon, 29 Oct 2007) $
# Parameters: [MATCH_1 [MATCH_2 [MATCH_n]]]
# Requires:   AP_PROG_APXS
# Output:     @HTTPD_VERSION@ - Apache HTTPD version
#
# The AP_HTTPD_VERSION macro uses apxs to determine the path of the apache
# httpd binary and invokes it with the `-v' command line switch. It extracts
# the version string from the output and compares it to any given parameter.
# You can optionally give one or more `MATCH' parameters to the macro to make
# sure HTTPD has a certain required version. Parameters must be separated by
# whitespace.
#
# The format for the parameters is: [COMPARATOR]VERSION
# The `VERSION' part can be any Apache HTTPD version (sub)string to compare to.
# The optional COMPARATOR' part can be one of:
#    =  equal to (default if not given)
#    >  greater than
#    <  less than
#   !=  not equal to
#   >=  greater or equal
#   <=  less or equal
#
# Thus, the strings `>1' and `>=2.0.0' both match HTTPD version 2.x.x and higher.
# If parameters are given, one of them must match or a error message is
# displayed and execution of configure is halted. It is sufficient that only
# one of multiple parameters matches for the macro not to fail (logical OR).
#
AC_DEFUN([AP_HTTPD_VERSION],
[
	AC_REQUIRE([AP_PROG_APXS])
	ap_httpd="`$APXS -q SBINDIR`/`$APXS -q TARGET`"
	ap_httpd_version="`$ap_httpd -v | grep 'version' | sed -e 's!.*/\(.*\)$!\1!'`"

	if test "x$1" != "x"
	then
		AC_MSG_CHECKING([for apache httpd version])
		AC_MSG_RESULT([$ap_httpd_version])
		for ap_param in m4_foreach_w([var], m4_quote($*), ['var' ])
		do
			ap_param_cmp="`echo $ap_param | sed -e 's/[[^!<>=]]*\([[!<>=]]*\).*/\1/'`"
			ap_param_ver="`echo $ap_param | sed -e 's/[[^[:digit:]]]*\([[[:digit:].]]*[[[:digit:]]]\).*/\1/'`"
			ap_param_ver_size="`echo $ap_param_ver | tr '.' ' ' | wc -w`"
			ap_cmp_ver="`echo $ap_httpd_version | cut -d. -f1-$ap_param_ver_size`"

			if expr $ap_cmp_ver ${ap_param_cmp:-'='} $ap_param_ver >/dev/null
			then
				ap_works="$ap_param"
				break
			fi
		done
		if test "x$ap_works" = "x"
		then
			AC_MSG_ERROR([apache version $1 is required])
		fi
	fi

	AC_SUBST([HTTPD_VERSION])
])



#
# Macro:      AP_APACHE_MODULE
# Author:     Heiko Hund <heiko@ist.eigentlich.net>
# Version:    $Revision: 36 $ $Date: 2007-10-29 21:29:34 +0100 (Mon, 29 Oct 2007) $
# Parameters: MATCH_1 [MATCH_2 [MATCH_n]]
# Requires:   AP_HTTPD_VERSION
# Output:     @AP_MOD_DIR@     - Apache HTTPD modules directory
#             @AP_MOD_CFLAGS@  - CFLAGS for module compilation
#             @AP_MOD_LDFLAGS@ - LDFLAGS for linking modules
#
# The AP_APACHE_MODULE macro uses apxs to gather information needed to build
# dynamically loadable modules for Apache HTTPD. It takes one or more `MATCH'
# parameters that ensure the module is built for the Apache version the module
# was made for. If multiple parameters are given, they must be separated by
# whitespace.
#
# The format for the parameters is: [COMPARATOR]VERSION
# The `VERSION' part can be any Apache HTTPD version (sub)string to compare to.
# The optional COMPARATOR' part can be one of:
#    =  equal to (default if not given)
#    >  greater than
#    <  less than
#   !=  not equal to
#   >=  greater or equal
#   <=  less or equal
#
# Thus, the strings `>1' and `>=2.0.0' both match HTTPD version 2.x.x and higher.
# One of the parameters must match or a error message is displayed and execution
# of configure is halted. It is sufficient that only one of multiple parameters
# matches for the macro not to fail (logical OR).
#
AC_DEFUN([AP_APACHE_MODULE],
[
	AC_REQUIRE([AP_HTTPD_VERSION])

	AC_MSG_CHECKING([if module works with apache httpd version $ap_httpd_version])
	for ap_param in m4_foreach_w([var], m4_quote($*), ['var' ])
	do
		ap_param_cmp="`echo $ap_param | sed -e 's/[[^!<>=]]*\([[!<>=]]*\).*/\1/'`"
		ap_param_ver="`echo $ap_param | sed -e 's/[[^[:digit:]]]*\([[[:digit:].]]*[[[:digit:]]]\).*/\1/'`"
		ap_param_ver_size="`echo $ap_param_ver | tr '.' ' ' | wc -w`"
		ap_cmp_ver="`echo $ap_httpd_version | cut -d. -f1-$ap_param_ver_size`"

		if expr $ap_cmp_ver ${ap_param_cmp:-'='} $ap_param_ver >/dev/null
		then
			ap_mod_works="$ap_param"
			break
		fi
	done
	if test "x$ap_mod_works" = "x"
	then
		AC_MSG_RESULT([no])
		AC_MSG_ERROR([module only works with apache httpd version $*])
	else
		AC_MSG_RESULT([yes ($ap_mod_works)])
	fi

	AC_SUBST([AP_MOD_CFLAGS], ["`$APXS -q CFLAGS_SHLIB` -I`$APXS -q INCLUDEDIR` \
	                            `$APXS -q EXTRA_INCLUDES 2>/dev/null` `$APXS -q EXTRA_CPPFLAGS 2>/dev/null`"])
	AC_SUBST([AP_MOD_LDFLAGS], ["`$APXS -q LDFLAGS_SHLIB` `$APXS -q LIBS_SHLIB`"])
	AC_SUBST([AP_MOD_DIR], [`$APXS -q LIBEXECDIR`])
])
